@@ -23,6 +23,7 @@
 #include <messagelist/view.h>
 #include <QHash>
 #include <QTabWidget>
+#include <QVector>
 
 #include <kmime/kmime_message.h>
 #include <collection.h>
@@ -81,7 +82,7 @@ public:
     * Returns the current message for the list as Akonadi::Item.
     * May return an invalid Item if there is no current message or no current folder.
     */
-    Akonadi::Item currentItem() const;
+    Q_REQUIRED_RESULT Akonadi::Item currentItem() const;
 
     /**
     * Returns the current message for the list as KMime::Message::Ptr.
@@ -100,7 +101,7 @@ public:
     * to the main even loop. Don't store it for any longer. If you need to reference
     * this set of messages at a later stage then take a look at createPersistentSet().
     */
-    QList<KMime::Message::Ptr > selectionAsMessageList(bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT QVector<KMime::Message::Ptr> selectionAsMessageList(bool includeCollapsedChildren = true) const;
 
     /**
     * Returns the currently selected Items (bound to current StorageModel).
@@ -113,7 +114,7 @@ public:
     * to the main even loop. Don't store it for any longer. If you need to reference
     * this set of messages at a later stage then take a look at createPersistentSet().
     */
-    Akonadi::Item::List selectionAsMessageItemList(bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT Akonadi::Item::List selectionAsMessageItemList(bool includeCollapsedChildren = true) const;
 
     /**
     * Returns the currently selected Items id(bound to current StorageModel).
@@ -126,9 +127,9 @@ public:
     * to the main even loop. Don't store it for any longer. If you need to reference
     * this set of messages at a later stage then take a look at createPersistentSet().
     */
-    QVector<qlonglong> selectionAsMessageItemListId(bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT QVector<qlonglong> selectionAsMessageItemListId(bool includeCollapsedChildren = true) const;
 
-    QList<Akonadi::Item::Id> selectionAsListMessageId(bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT QVector<Akonadi::Item::Id> selectionAsListMessageId(bool includeCollapsedChildren = true) const;
 
     /**
     * Returns the Akonadi::Item bound to the current StorageModel that
@@ -140,7 +141,7 @@ public:
     * to the main even loop. Don't store it for any longer. If you need to reference
     * this set of messages at a later stage then take a look at createPersistentSet().
     */
-    Akonadi::Item::List currentThreadAsMessageList() const;
+    Q_REQUIRED_RESULT Akonadi::Item::List currentThreadAsMessageList() const;
 
     /**
     * Selects the next message item in the view.
@@ -155,7 +156,7 @@ public:
     * If loop is true then the "next" algorithm will restart from the beginning
     * of the list if the end is reached, otherwise it will just stop returning false.
     */
-    bool selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
+    Q_REQUIRED_RESULT bool selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
 
     /**
     * Selects the previous message item in the view.
@@ -170,7 +171,7 @@ public:
     * If loop is true then the "previous" algorithm will restart from the end
     * of the list if the beginning is reached, otherwise it will just stop returning false.
     */
-    bool selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
+    Q_REQUIRED_RESULT bool selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop);
 
     /**
     * Focuses the next message item in the view without actually selecting it.
@@ -182,7 +183,7 @@ public:
     * If loop is true then the "next" algorithm will restart from the beginning
     * of the list if the end is reached, otherwise it will just stop returning false.
     */
-    bool focusNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop);
+    Q_REQUIRED_RESULT bool focusNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop);
 
     /**
     * Focuses the previous message item in the view without actually selecting it.
@@ -194,7 +195,7 @@ public:
     * If loop is true then the "previous" algorithm will restart from the end
     * of the list if the beginning is reached, otherwise it will just stop returning false.
     */
-    bool focusPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop);
+    Q_REQUIRED_RESULT bool focusPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop);
 
     /**
     * Selects the currently focused message item. May do nothing if the
@@ -219,7 +220,7 @@ public:
     *
     * The function returns true if a message was selected and false otherwise.
     */
-    bool selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem);
+    Q_REQUIRED_RESULT bool selectFirstMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem);
 
     /**
     * Selects the last message item in the view that matches the specified Core::MessageTypeFilter.
@@ -228,7 +229,7 @@ public:
     *
     * The function returns true if a message was selected and false otherwise.
     */
-    bool selectLastMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem);
+    Q_REQUIRED_RESULT bool selectLastMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem);
 
     /**
     * If expand is true then it expands the current thread, otherwise
@@ -258,23 +259,23 @@ public:
     /**
     * Returns the Akonadi::MessageStatus in the current quicksearch field.
     */
-    QList<Akonadi::MessageStatus> currentFilterStatus() const;
+    Q_REQUIRED_RESULT QVector<Akonadi::MessageStatus> currentFilterStatus() const;
 
     /**
     * Returns the search term in the current quicksearch field.
     */
-    QString currentFilterSearchString() const;
+    Q_REQUIRED_RESULT QString currentFilterSearchString() const;
 
     /**
     * Returns true if the current Aggregation is threaded, false otherwise
     * (or if there is no current Aggregation).
     */
-    bool isThreaded() const;
+    Q_REQUIRED_RESULT bool isThreaded() const;
 
     /**
     * Fast function that determines if the selection is empty
     */
-    bool selectionEmpty() const;
+    Q_REQUIRED_RESULT bool selectionEmpty() const;
     /**
     * Fills the lists of the selected message serial numbers and of the selected+visible ones.
     * Returns true if the returned stats are valid (there is a current folder after all)
@@ -284,7 +285,7 @@ public:
     * If includeCollapsedChildren is true then the children of the selected but
     * collapsed items are also included in the stats
     */
-    bool getSelectionStats(Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT bool getSelectionStats(Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren = true) const;
     /**
     * Deletes the persistent set pointed by the specified reference.
     * If the set does not exist anymore, nothing happens.
@@ -302,17 +303,17 @@ public:
     /**
     * Return Akonadi::Item from messageItemReference
     */
-    Akonadi::Item::List itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref);
+    Q_REQUIRED_RESULT Akonadi::Item::List itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref);
 
     /**
     * Return a persistent set from current selection
     */
-    MessageList::Core::MessageItemSetReference selectionAsPersistentSet(bool includeCollapsedChildren = true) const;
+    Q_REQUIRED_RESULT MessageList::Core::MessageItemSetReference selectionAsPersistentSet(bool includeCollapsedChildren = true) const;
 
     /**
     * Return a persistent set from current thread
     */
-    MessageList::Core::MessageItemSetReference currentThreadAsPersistentSet() const;
+    Q_REQUIRED_RESULT MessageList::Core::MessageItemSetReference currentThreadAsPersistentSet() const;
     /**
     * Sets the focus on the view of the currently active tab.
     */
@@ -335,6 +336,8 @@ public:
     * If the specified folder is not open yet then behaviour
     * depends on the preferEmptyTab value as follows.
     *
+    * @param etmIndex the index for the collection in the EntityTreeModel (source model)
+    *
     * If preferEmptyTab is set to false then the (new) folder is loaded
     * in the current tab. If preferEmptyTab is set to true then the (new) folder is
     * loaded in the first empty tab (or a new one if there are no empty ones).
@@ -347,8 +350,7 @@ public:
     * like "loading..."
     */
     void setCurrentFolder(
-        const Akonadi::Collection &fld, bool preferEmptyTab = false, MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected,
-        const QString &overrideLabel = QString());
+        const Akonadi::Collection &fld, const QModelIndex &etmIndex, bool preferEmptyTab = false, MessageList::Core::PreSelectionMode preSelectionMode = MessageList::Core::PreSelectLastSelected, const QString &overrideLabel = QString());
 
     void resetModelStorage();
 
@@ -368,7 +370,7 @@ public:
 
     Core::QuickSearchLine::SearchOptions currentOptions() const;
 
-    Akonadi::Collection currentFolder() const;
+    Q_REQUIRED_RESULT Akonadi::Collection currentFolder() const;
 
 public Q_SLOTS:
     /**
@@ -434,11 +436,6 @@ private:
     void restoreHeaderSettings(int index);
     void readConfig(bool restoreSession);
 
-    Q_PRIVATE_SLOT(d, void onSelectionChanged(const QItemSelection &, const QItemSelection &))
-    Q_PRIVATE_SLOT(d, void closeTab(QWidget *))
-    Q_PRIVATE_SLOT(d, void updateTabControls())
-    Q_PRIVATE_SLOT(d, void changeQuicksearchVisibility(bool))
-
     bool eventFilter(QObject *obj, QEvent *event) override;
 
     class Private;
