@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,24 +25,26 @@
 
 namespace MessageViewer {
 class GrantleeHeaderTestStylePrivate;
+/**
+ * @brief The GrantleeHeaderTestStyle class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT GrantleeHeaderTestStyle : public HeaderStyle
 {
     friend class GrantleeHeaderStyle;
 public:
     GrantleeHeaderTestStyle();
-    ~GrantleeHeaderTestStyle();
+    ~GrantleeHeaderTestStyle() override;
 
 public:
     const char *name() const override;
 
-    QString format(KMime::Message *message) const override;
+    Q_REQUIRED_RESULT QString format(KMime::Message *message) const override;
 
     void setAbsolutePath(const QString &);
     void setMainFilename(const QString &);
     void setExtraDisplayHeaders(const QStringList &);
 
-    bool hasAttachmentQuickList() const override;
-
 private:
     GrantleeHeaderTestStylePrivate *const d;
 };
