@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,16 +31,19 @@
 #include "messageviewer/headerstyle.h"
 #include "messageviewer/viewer.h"
 #include "messageviewer_export.h"
-namespace MessageViewer
-{
+namespace MessageViewer {
+/**
+ * @brief The HeaderStyleUtil class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT HeaderStyleUtil
 {
 public:
     HeaderStyleUtil();
     struct xfaceSettings {
         xfaceSettings()
-            : photoWidth(60),
-              photoHeight(60)
+            : photoWidth(60)
+            , photoHeight(60)
         {
         }
 
@@ -60,35 +63,31 @@ public:
         CustomDate
     };
 
-    QString directionOf(const QString &str) const;
+    Q_REQUIRED_RESULT QString directionOf(const QString &str) const;
 
-    QString strToHtml(const QString &str, KTextToHTML::Options flags = KTextToHTML::PreserveSpaces) const;
+    static Q_REQUIRED_RESULT QString strToHtml(const QString &str, KTextToHTML::Options flags = KTextToHTML::PreserveSpaces);
+    static Q_REQUIRED_RESULT QString dateString(KMime::Message *message, HeaderStyleUtilDateFormat dateFormat);
+    static Q_REQUIRED_RESULT QString dateString(const QDateTime &date, HeaderStyleUtilDateFormat dateFormat);
 
-    QString dateString(KMime::Message *message, bool printing, HeaderStyleUtilDateFormat dateFormat) const;
+    Q_REQUIRED_RESULT QString subjectString(KMime::Message *message, KTextToHTML::Options flags = KTextToHTML::PreserveSpaces) const;
 
-    QString subjectString(KMime::Message *message, KTextToHTML::Options flags = KTextToHTML::PreserveSpaces) const;
+    Q_REQUIRED_RESULT QString subjectDirectionString(KMime::Message *message) const;
 
-    QString subjectDirectionString(KMime::Message *message) const;
+    Q_REQUIRED_RESULT QString spamStatus(KMime::Message *message) const;
 
-    QString mailAction(MessageViewer::Viewer::MailAction action) const;
+    static Q_REQUIRED_RESULT QString dateStr(const QDateTime &dateTime);
 
-    QString spamStatus(KMime::Message *message) const;
+    static Q_REQUIRED_RESULT QString dateShortStr(const QDateTime &dateTime);
 
-    QString dateStr(const QDateTime &dateTime) const;
+    MESSAGEVIEWER_DEPRECATED static Q_REQUIRED_RESULT QSharedPointer<KMime::Headers::Generics::MailboxList> resentFromList(KMime::Message *message);
 
-    QString dateShortStr(const QDateTime &dateTime) const;
+    MESSAGEVIEWER_DEPRECATED static Q_REQUIRED_RESULT QSharedPointer<KMime::Headers::Generics::MailboxList> resentToList(KMime::Message *message);
 
-    QVector<KMime::Types::Mailbox> resentFromList(KMime::Message *message) const;
-    QVector<KMime::Types::Mailbox> resentToList(KMime::Message *message) const;
-
-    xfaceSettings xface(const HeaderStyle *style, KMime::Message *message) const;
-    void addMailAction(QVariantHash &headerObject);
+    Q_REQUIRED_RESULT xfaceSettings xface(const HeaderStyle *style, KMime::Message *message) const;
 private:
     void updateXFaceSettings(QImage photo, xfaceSettings &settings) const;
-    QString drawSpamMeter(SpamError spamError, double percent, double confidence,
-                          const QString &filterHeader, const QString &confidenceHeader) const;
-    QString imgToDataUrl(const QImage &image) const;
-    int mIconSize;
+    Q_REQUIRED_RESULT QString drawSpamMeter(SpamError spamError, double percent, double confidence, const QString &filterHeader, const QString &confidenceHeader) const;
+    Q_REQUIRED_RESULT QString imgToDataUrl(const QImage &image) const;
 };
 }
 
